@@ -30,9 +30,16 @@ def replace_str(start_str,end_str,replace_str,str):
 
 def find_str(start_str,end_str,str):
     """
-    查找以XX开头以XX结尾的字符串,返回找到的列表 
+    查找以XX开头以XX结尾的字符串,返回找到的列表 (包含开头结尾)
     """
     re_formula = f"{start_str}.*?{end_str}"
     result = re.findall(re_formula, str)
     return result
 
+def find_str_cent(start_str,end_str,str):
+    """
+    查找以XX开头以XX结尾的字符串,返回找到的列表 （不包含开头结尾）
+    """
+    re_formula = f"{start_str}(.*?){end_str}"
+    result = re.findall(re_formula, str)
+    return result
