@@ -374,13 +374,13 @@ def judge_time(ti: str, st: str, en: str, year:bool=True):
     :return: True or  False
     """
     if year:
-        d_time_st = datetime.datetime.strptime(ti, '%Y-%m-%d %H:%M:%S')
-        d_time_en = datetime.datetime.strptime(st, '%Y-%m-%d %H:%M:%S')
-        n_time = datetime.datetime.strptime(en, '%Y-%m-%d %H:%M:%S')
+        d_time_st = datetime.datetime.strptime(st, '%Y-%m-%d %H:%M:%S')
+        d_time_en = datetime.datetime.strptime(en, '%Y-%m-%d %H:%M:%S')
+        n_time = datetime.datetime.strptime(ti, '%Y-%m-%d %H:%M:%S')
     else:
-        d_time_st = datetime.datetime.strptime(ti, '%H:%M:%S')
-        d_time_en = datetime.datetime.strptime(st, '%H:%M:%S')
-        n_time = datetime.datetime.strptime(en, '%H:%M:%S')
+        d_time_st = datetime.datetime.strptime(st, '%H:%M:%S')
+        d_time_en = datetime.datetime.strptime(en, '%H:%M:%S')
+        n_time = datetime.datetime.strptime(ti, '%H:%M:%S')
     assert d_time_en > d_time_st, "时间范围需结束时间大于开始时间！"
     if n_time > d_time_st and n_time < d_time_en:
         return True
@@ -412,5 +412,7 @@ def get_taobao_time():
 
 
 if __name__ == '__main__':
-    # month_begin_day = month_datelist('2020-01')
-    print(get_taobao_time())
+    now_time = get_now_time("%H:%M:%S")
+    print(now_time)
+    flag = judge_time(now_time, "02:00:00", "05:00:00", year=False)
+    print(flag)
